@@ -21,6 +21,18 @@ func TestTestifyLint(t *testing.T) {
 			dir:   "base-test",
 			flags: map[string]string{"disable-all": "true", "enable": checkers.NewBoolCompare().Name()},
 		},
+		{
+			dir:   "bool-compare-custom-types",
+			flags: map[string]string{"disable-all": "true", "enable": checkers.NewBoolCompare().Name()},
+		},
+		{
+			dir: "bool-compare-ignore-custom-types",
+			flags: map[string]string{
+				"disable-all":                      "true",
+				"enable":                           checkers.NewBoolCompare().Name(),
+				"bool-compare.ignore-custom-types": "true",
+			},
+		},
 		{
 			dir:   "checkers-priority",
 			flags: map[string]string{"enable-all": "true"},
@@ -29,6 +41,10 @@ func TestTestifyLint(t *testing.T) {
 			dir:   "error-as-target",
 			flags: map[string]string{"disable-all": "true", "enable": checkers.NewErrorIsAs().Name()},
 		},
+		{
+			dir:   "error-nil-issue95",
+			flags: map[string]string{"disable-all": "true", "enable": checkers.NewErrorNil().Name()},
+		},
 		{
 			dir: "expected-var-custom-pattern",
 			flags: map[string]string{
@@ -37,7 +53,28 @@ func TestTestifyLint(t *testing.T) {
 				"expected-actual.pattern": "goldenValue",
 			},
 		},
-		{dir: "ginkgo"},
+		{
+			dir: "ginkgo",
+		},
+		{
+			dir: "go-require-http-handlers",
+			flags: map[string]string{
+				"enable": checkers.NewGoRequire().Name() + "," + // https://github.com/Antonboom/testifylint/issues/66
+					checkers.NewRequireError().Name(), // https://github.com/Antonboom/testifylint/issues/73
+			},
+		},
+		{
+			dir: "go-require-ignore-http-handlers",
+			flags: map[string]string{
+				"disable-all":                     "true",
+				"enable":                          checkers.NewGoRequire().Name(),
+				"go-require.ignore-http-handlers": "true",
+			},
+		},
+		{
+			dir:   "go-require-issue67",
+			flags: map[string]string{"disable-all": "true", "enable": checkers.NewGoRequire().Name()},
+		},
 		{
 			dir:   "not-std-funcs",
 			flags: map[string]string{"enable-all": "true"},
@@ -79,7 +116,7 @@ func TestTestifyLint(t *testing.T) {
 					t.Fatal(err)
 				}
 			}
-			analysistest.RunWithSuggestedFixes(t, analysistest.TestData(), anlzr, tt.dir)
+			analysistest.RunWithSuggestedFixes(t, analysistest.TestData(), anlzr, filepath.Join(tt.dir, "..."))
 		})
 	}
 }
