@@ -15,9 +15,15 @@ func NewDefault() Config {
 		DisabledCheckers: nil,
 		DisableAll:       false,
 		EnabledCheckers:  nil,
+		BoolCompare: BoolCompareConfig{
+			IgnoreCustomTypes: false,
+		},
 		ExpectedActual: ExpectedActualConfig{
 			ExpVarPattern: RegexpValue{checkers.DefaultExpectedVarPattern},
 		},
+		GoRequire: GoRequireConfig{
+			IgnoreHTTPHandlers: false,
+		},
 		RequireError: RequireErrorConfig{
 			FnPattern: RegexpValue{nil},
 		},
@@ -34,16 +40,28 @@ type Config struct {
 	DisableAll       bool
 	EnabledCheckers  KnownCheckersValue
 
+	BoolCompare          BoolCompareConfig
 	ExpectedActual       ExpectedActualConfig
+	GoRequire            GoRequireConfig
 	RequireError         RequireErrorConfig
 	SuiteExtraAssertCall SuiteExtraAssertCallConfig
 }
 
+// BoolCompareConfig implements configuration of checkers.BoolCompare.
+type BoolCompareConfig struct {
+	IgnoreCustomTypes bool
+}
+
 // ExpectedActualConfig implements configuration of checkers.ExpectedActual.
 type ExpectedActualConfig struct {
 	ExpVarPattern RegexpValue
 }
 
+// GoRequireConfig implements configuration of checkers.GoRequire.
+type GoRequireConfig struct {
+	IgnoreHTTPHandlers bool
+}
+
 // RequireErrorConfig implements configuration of checkers.RequireError.
 type RequireErrorConfig struct {
 	FnPattern RegexpValue
@@ -91,7 +109,11 @@ func BindToFlags(cfg *Config, fs *flag.FlagSet) {
 	fs.BoolVar(&cfg.DisableAll, "disable-all", false, "disable all checkers")
 	fs.Var(&cfg.EnabledCheckers, "enable", "comma separated list of enabled checkers (in addition to enabled by default)")
 
+	fs.BoolVar(&cfg.BoolCompare.IgnoreCustomTypes, "bool-compare.ignore-custom-types", false,
+		"to ignore user defined types (over builtin bool)")
 	fs.Var(&cfg.ExpectedActual.ExpVarPattern, "expected-actual.pattern", "regexp for expected variable name")
+	fs.BoolVar(&cfg.GoRequire.IgnoreHTTPHandlers, "go-require.ignore-http-handlers", false,
+		"to ignore HTTP handlers (like http.HandlerFunc)")
 	fs.Var(&cfg.RequireError.FnPattern, "require-error.fn-pattern", "regexp for error assertions that should only be analyzed")
 	fs.Var(NewEnumValue(suiteExtraAssertCallModeAsString, &cfg.SuiteExtraAssertCall.Mode),
 		"suite-extra-assert-call.mode", "to require or remove extra Assert() call")
